pub struct ApprovalQueue { /* private fields */ }Implementations
Sourceimpl ApprovalQueue
impl ApprovalQueue
pub fn new(max_pending: usize, default_timeout: Duration) -> Self
pub fn on_push<F>(self, f: F) -> Self
pub fn on_resolve<F>(self, f: F) -> Self
pub fn size(&self) -> usize
pub fn list(&self) -> Vec<ApprovalRequest>
Sourcepub async fn push(
&self,
request: ApprovalRequest,
) -> Result<ApprovalResult, ApprovalError>
pub async fn push( &self, request: ApprovalRequest, ) -> Result<ApprovalResult, ApprovalError>
Enqueue a request and await a decision. Resolves with Deny if the default timeout elapses first.
Sourcepub fn respond(
&self,
request_id: &str,
decision: ApprovalDecision,
note: Option<String>,
) -> bool
pub fn respond( &self, request_id: &str, decision: ApprovalDecision, note: Option<String>, ) -> bool
Resolve a pending request. Returns true if a matching request was found and resolved.
Sourcepub fn drain_deny(&self, reason: &str)
pub fn drain_deny(&self, reason: &str)
Cancel every outstanding approval with Deny + reason.