pub struct DeliveryReceipt {
pub receipt_version: String,
pub packet_id: String,
pub packet_hash: String,
pub receiver: String,
pub received_at: String,
pub signature: ReceiptSignature,
}Fields
receipt_version: Stringpacket_id: Stringpacket_hash: Stringsha256:<hex> digest of the verified packet payload, so the
receipt is bound to the actual bytes the receiver saw.
receiver: Stringreceived_at: Stringsignature: ReceiptSignatureTrait Implementations
Sourceimpl Clone for DeliveryReceipt
impl Clone for DeliveryReceipt
Sourcefn clone(&self) -> DeliveryReceipt
fn clone(&self) -> DeliveryReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeliveryReceipt
impl Debug for DeliveryReceipt
Sourceimpl<'de> Deserialize<'de> for DeliveryReceipt
impl<'de> Deserialize<'de> for DeliveryReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryReceipt
Sourceimpl PartialEq for DeliveryReceipt
impl PartialEq for DeliveryReceipt
Sourcefn eq(&self, other: &DeliveryReceipt) -> bool
fn eq(&self, other: &DeliveryReceipt) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DeliveryReceipt
impl Serialize for DeliveryReceipt
impl StructuralPartialEq for DeliveryReceipt