TelemetryHandler

Type Alias TelemetryHandler 

pub type TelemetryHandler = Arc<dyn Fn(Value, RpcContext, StreamingPriority, UnboundedReceiver<Result<Value, RpcError>>) -> Pin<Box<dyn Future<Output = Result<(), RpcError>> + Send>> + Send + Sync>;
Telemetry handler — push-only client-streaming with the declared streaming priority surfaced in ctx. Returns Ok(()) to commit a success closing frame, Err to fail the call.

Aliased Type

pub struct TelemetryHandler { /* private fields */ }