pub fn as_shadow_decision(d: GuardDecision) -> GuardDecisionExpand description
Shadow-mode helper: take an arbitrary GuardDecision and return what the daemon would do at EnforcementLevel E0 (record-only).
pub fn as_shadow_decision(d: GuardDecision) -> GuardDecisionShadow-mode helper: take an arbitrary GuardDecision and return what the daemon would do at EnforcementLevel E0 (record-only).