EvidenceArchive

Trait EvidenceArchive 

pub trait EvidenceArchive: Send + Sync {
    // Required methods
    fn put(&self, bundle_id: &str, bytes: &[u8]) -> Result<(), StoreError>;
    fn get(&self, bundle_id: &str) -> Result<Option<Vec<u8>>, StoreError>;
    fn list(&self) -> Result<Vec<String>, StoreError>;
}
Opaque-byte evidence-bundle archive (e.g. compliance bundles per TF-0012). Bundles are addressed by an external bundle id, not a content hash, because callers may want to overwrite or version a bundle outside the archive’s responsibility.

Required Methods

fn put(&self, bundle_id: &str, bytes: &[u8]) -> Result<(), StoreError>

fn get(&self, bundle_id: &str) -> Result<Option<Vec<u8>>, StoreError>

fn list(&self) -> Result<Vec<String>, StoreError>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors